@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Aug 2002
 ;;;;
-;;;; $Id: downloads.lisp 7061 2003-09-07 06:34:45Z kevin $
+;;;; $Id$
 ;;;;
 ;;;; This file, part of LML, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -32,32 +32,32 @@
 
 (defun strip-dl-base (file)
   (let ((fdir (pathname-directory file))
-	(bdir (pathname-directory *dl-base*)))
+        (bdir (pathname-directory *dl-base*)))
     (make-pathname
      :name (pathname-name file)
      :type (pathname-type file)
-     :directory 
+     :directory
      (when (> (length fdir) (length bdir))
-       (append '(:absolute) 
-	       (subseq fdir (length bdir) (length fdir)))))))
-     
+       (append '(:absolute)
+               (subseq fdir (length bdir) (length fdir)))))))
+
 (defun print-file (file)
   (let ((size 0)
-	(modtime (date-string (file-write-date file)))
-	(basename (namestring
-		   (make-pathname :name (pathname-name file)
-				  :type (pathname-type file))))
-	(dl-name (strip-dl-base file))
-	(sig-path (concatenate 'string (namestring file) ".asc")))
+        (modtime (date-string (file-write-date file)))
+        (basename (namestring
+                   (make-pathname :name (pathname-name file)
+                                  :type (pathname-type file))))
+        (dl-name (strip-dl-base file))
+        (sig-path (concatenate 'string (namestring file) ".asc")))
     (when (plusp (length basename))
       (with-open-file (strm file :direction :input)
-		      (setq size (round (/ (file-length strm) 1024))))
+                      (setq size (round (/ (file-length strm) 1024))))
       (lml-format "<a href=\"~A~A\">~A</a>" *dl-url* dl-name basename)
       (lml-princ "<span class=\"modtime\">")
       (lml-format " (~A, <b>~:D <span style=\"font-size:90%;\">KB</span></b>)</span>" modtime size)
       (when (probe-file sig-path)
-	(setq *signed* t)
-	(lml-format " [<a href=\"~A~A.asc\">Signature</a>]" *dl-url* dl-name))
+        (setq *signed* t)
+        (lml-format " [<a href=\"~A~A.asc\">Signature</a>]" *dl-url* dl-name))
       (br))))
 
 (defun display-header (name url)
@@ -71,7 +71,7 @@
     (lml-princ "<h3>GPG Public Key</h3>")
     (lml-princ "Use this <a href=\"https://www.b9.com/kevin.gpg.asc\">key</a> to verify file signtatures"))
   (lml-princ "</div>"))
-  
+
 (defun print-sect-title (title)
   (lml-format "<h~D>~A</h~D>" *section-indent* title *section-indent*))
 
@@ -82,7 +82,7 @@
 
 (defun match-base-name-latest? (name)
   (let* ((latest (concatenate 'string *base-name* "-latest"))
-	 (len-latest (length latest)))
+         (len-latest (length latest)))
     (when (>= (length name) len-latest)
       (string= name latest :end1 len-latest :end2 len-latest))))
 
@@ -97,7 +97,7 @@
 
 (defun display-one-section (title pat)
   (let ((files (sort-pathnames (filter-latest
-				(filter-against-base (directory pat))))))
+                                (filter-against-base (directory pat))))))
     (when files
       (print-sect-title title)
       (lml-princ "<div style=\"padding-left: 20pt;\">")
@@ -107,62 +107,66 @@
 (defun display-sections (sects)
   (when sects
     (let ((title (car sects))
-	  (value (cadr sects)))
+          (value (cadr sects)))
       (if (consp title)
-	  (dolist (sect sects) (display-sections sect))
-	(if (consp value)
-	    (progn
-	      (print-sect-title title)
-	      (incf *section-indent*)
-	      (display-sections value)
-	      (decf *section-indent*))
-	  (display-one-section title value))))))
-      
-(defun display-page (pkg-name pkg-base dl-base dl-url sects)
+          (dolist (sect sects) (display-sections sect))
+        (if (consp value)
+            (progn
+              (print-sect-title title)
+              (incf *section-indent*)
+              (display-sections value)
+              (decf *section-indent*))
+          (display-one-section title value))))))
+
+(defun display-page (pkg-name pkg-base dl-base dl-url giturl gitweb sects)
   (let ((*section-indent* 3)
-	(*dl-base* dl-base)
-	(*dl-url* dl-url)
-	(*base-name* pkg-base)
-	(*signed* nil))
+        (*dl-base* dl-base)
+        (*dl-url* dl-url)
+        (*base-name* pkg-base)
+        (*signed* nil))
     (display-header pkg-name dl-url)
     (map nil #'display-sections sects)
+    (when giturl
+      (lml-format "<h2>Git Repository</h2><tt>~A</tt>" giturl)
+      (when gitweb
+        (lml-format "&nbsp;&nbsp;[<a href=\"~A\">Browse</a>]" gitweb)))
     (display-footer)))
 
-(defun std-dl-page (pkg-name pkg-base dl-base dl-url)
+(defun std-dl-page (pkg-name pkg-base dl-base dl-url &optional giturl gitweb)
   (let ((base (parse-namestring dl-base)))
     (let ((tgz-path (make-pathname :defaults base :type "gz" :name :wild))
-	  (zip-path (make-pathname :defaults base :type "zip" :name :wild))
-	  (doc-path (make-pathname :defaults base :type "pdf" :name :wild)))
-      (display-page pkg-name pkg-base dl-base dl-url
-		    `(("Manual" ,doc-path)
-		      ("Source Code"
-		       (("Unix (.tar.gz)" ,tgz-path)
-			("Windows (.zip)" ,zip-path))))))))
-  
-(defun full-dl-page (pkg-name pkg-base dl-base dl-url)
+          (zip-path (make-pathname :defaults base :type "zip" :name :wild))
+          (doc-path (make-pathname :defaults base :type "pdf" :name :wild)))
+      (display-page pkg-name pkg-base dl-base dl-url giturl gitweb
+                    `(("Manual" ,doc-path)
+                      ("Source Code"
+                       (("Unix (.tar.gz)" ,tgz-path)
+                        ("Windows (.zip)" ,zip-path))))))))
+
+(defun full-dl-page (pkg-name pkg-base dl-base dl-url &optional giturl gitweb)
   (let ((base (parse-namestring dl-base)))
     (let ((tgz-path (make-pathname :defaults base :type "gz" :name :wild))
-	  (zip-path (make-pathname :defaults base :type "zip" :name :wild))
-	  (doc-path (make-pathname :defaults base :type "pdf" :name :wild))
-	  (deb-path (merge-pathnames
-		     (make-pathname :directory '(:relative "linux-debian")
-				    :type :wild :name :wild)
-		     base))
-	  (rpm-path (merge-pathnames
-		     (make-pathname :directory '(:relative "linux-rpm")
-				    :type :wild :name :wild)
-		     base))
-	  (w32-path (merge-pathnames
-		     (make-pathname :directory '(:relative "win32")
-				    :type :wild :name :wild)
-		     base)))
-      (display-page pkg-name pkg-base dl-base dl-url
-		    `(("Manual" ,doc-path)
-		      ("Source Code"
-		       (("Unix (.tar.gz)" ,tgz-path)
-			("Windows (.zip)" ,zip-path)))
-		      ("Binaries" 
-		       (("Linux Binaries"
-			 (("Debian Linux" ,deb-path)
-			  ("RedHat Linux" ,rpm-path)))
-			("Windows Binaries" ,w32-path))))))))
+          (zip-path (make-pathname :defaults base :type "zip" :name :wild))
+          (doc-path (make-pathname :defaults base :type "pdf" :name :wild))
+          (deb-path (merge-pathnames
+                     (make-pathname :directory '(:relative "linux-debian")
+                                    :type :wild :name :wild)
+                     base))
+          (rpm-path (merge-pathnames
+                     (make-pathname :directory '(:relative "linux-rpm")
+                                    :type :wild :name :wild)
+                     base))
+          (w32-path (merge-pathnames
+                     (make-pathname :directory '(:relative "win32")
+                                    :type :wild :name :wild)
+                     base)))
+      (display-page pkg-name pkg-base dl-base dl-url giturl gitweb
+                    `(("Manual" ,doc-path)
+                      ("Source Code"
+                       (("Unix (.tar.gz)" ,tgz-path)
+                        ("Windows (.zip)" ,zip-path)))
+                      ("Binaries"
+                       (("Linux Binaries"
+                         (("Debian Linux" ,deb-path)
+                          ("RedHat Linux" ,rpm-path)))
+                        ("Windows Binaries" ,w32-path))))))))
